@@ -14,17 +14,38 @@
 
 """Fleet Python SDK - Environment-based AI agent interactions."""
 
-from .exceptions import FleetError, FleetAPIError, FleetTimeoutError, FleetConfigurationError
+from .exceptions import (
+    FleetError,
+    FleetAPIError,
+    FleetTimeoutError,
+    FleetConfigurationError,
+)
 from .client import Fleet, AsyncFleet, InstanceRequest
+from .manager import (
+    ResetRequest,
+    ResetResponse,
+    CDPDescribeResponse,
+    ChromeStartRequest,
+    ChromeStartResponse,
+    ChromeStatusResponse,
+)
+from .verifiers import *
+from . import env
 
 __version__ = "0.1.1"
 __all__ = [
     "env",
     "FleetError",
-    "FleetAPIError", 
+    "FleetAPIError",
     "FleetTimeoutError",
     "FleetConfigurationError",
     "Fleet",
     "AsyncFleet",
     "InstanceRequest",
-] 
\ No newline at end of file
+    "ResetRequest",
+    "ResetResponse",
+    "CDPDescribeResponse",
+    "ChromeStartRequest",
+    "ChromeStartResponse",
+    "ChromeStatusResponse",
+]
